import { useEffect, useMemo, useRef, useState, } from 'react';
import { setPendingResult } from './use-async';
export const useAsyncCallback = (fn, deps) => {
    const [result, setResult] = useState({
        state: 'pending',
    });
    const controllerRef = useRef();
    const [callback, setCallback] = useState(() => {
        const controller = new AbortController();
        controllerRef.current = controller;
        const { signal } = controller;
        return (...args) => fn({ signal }, ...args).then(value => {
            if (!signal.aborted) {
                setResult({ state: 'fulfilled', value });
            }
            return value;
        }, reason => {
            if (!signal.aborted) {
                setResult({ state: 'rejected', reason });
            }
            throw reason;
        });
    });
    useEffect(() => {
        controllerRef.current.abort();
        const controller = new AbortController();
        controllerRef.current = controller;
        setResult(setPendingResult);
        setCallback(() => {
            const { signal } = controller;
            return (...args) => fn({ signal: controller.signal }, ...args).then(value => {
                if (!signal.aborted) {
                    setResult({ state: 'fulfilled', value });
                }
                return value;
            }, reason => {
                if (!signal.aborted) {
                    setResult({ state: 'rejected', reason });
                }
                throw reason;
            });
        });
        return () => {
            controller.abort();
        };
    }, deps);
    return useMemo(() => [callback, result], [callback, result]);
};
