/// <reference types="node" />
import { type DependencyList } from 'react';
export type UseAsyncState = 'pending' | 'rejected' | 'fulfilled';
export interface UseAsyncPendingResult {
    state: 'pending';
    reason?: never;
    value?: never;
}
export interface UseAsyncRejectedResult<TReason = unknown> {
    state: 'rejected';
    reason: TReason;
    value?: never;
}
export interface UseAsyncFulfilledResult<TValue> {
    state: 'fulfilled';
    reason?: never;
    value: TValue;
}
export type UseAsyncResult<TValue, TReason = unknown> = UseAsyncPendingResult | UseAsyncRejectedResult<TReason> | UseAsyncFulfilledResult<TValue>;
export declare const pending: unique symbol;
export declare const setPendingResult: (result: UseAsyncResult<unknown>) => UseAsyncPendingResult;
export declare const useAsync: <TValue, TReason = unknown>(fn: (options: {
    pending: typeof pending;
    signal: AbortSignal;
}) => PromiseLike<TValue | typeof pending>, deps: DependencyList) => UseAsyncResult<TValue, TReason>;
